import 'dart:convert';

import 'package:dd_taoke_sdk/model/brand_list_model.dart';
import 'package:dd_taoke_sdk/model/category.dart';
import 'package:dd_taoke_sdk/model/product.dart';
import 'package:dd_taoke_sdk/network/util.dart';
import 'package:dd_taoke_sdk/params/brand_param.dart';
import 'package:dd_taoke_sdk/params/brand_product_param.dart';
import 'package:dd_taoke_sdk/params/product_detail_param.dart';
import 'package:dd_taoke_sdk/params/product_list_param.dart';
import 'package:flutter/cupertino.dart';

import 'model/brand_detail_result.dart';
import 'model/carousel_model.dart';
import 'model/product.dart';
import 'model/product_list_result.dart';

class DdTaokeSdk {
  DdTaokeSdk._();

  static DdTaokeSdk get instance => DdTaokeSdk._();

  factory DdTaokeSdk() => instance;

  final util = DdTaokeUtil();

  /// 获取超级分类
  Future<List<Category>> getCategorys({ApiError error}) async {
    final response = await util.get('/categorys', error: error);
    return response.isNotEmpty ? categoryFromJson(response) : [];
  }

  /// 获取轮播图
  Future<List<Carousel>> getCarousel({ApiError error}) async {
    final response = await util.get('/carousel-list', error: error);
    return response.isNotEmpty ? carouselFromJson(response) : [];
  }

  /// 获取品牌列表
  Future<BrandListResult> getBrandList(
      {@required BrandListParam param, ApiError error}) async {
    final response =
        await util.get('/brand-list', data: param.toJson(), error: error);
    return response.isNotEmpty ? brandListResultFromJson(response) : null;
  }

  /// 获取商品列表
  Future<ProductListResult> getProducts(
      {@required ProductListParam param, ApiError error}) async {
    final response =
        await util.get('/goods', data: param.toJson(), error: error);
    return response.isNotEmpty ? productListFromJson(response) : null;
  }

  /// 获取商品详情
  Future<Product> getProductDetail(
      {@required ProductDetailParam param, ApiError error}) async {
    final response =
        await util.get('/detail', data: param.toJson(), error: error);
    return response.isNotEmpty ? Product.fromJson(jsonDecode(response)) : null;
  }

  /// 获取品牌详情
  Future<BrandDetail> getBrandDetail({@required BrandProductParam param,ApiError error}) async {
    final response = await util.get('/brand-detail',data: param.toJson(),error: error);
    return response.isNotEmpty ? BrandDetail.fromJson(jsonDecode(response)) : null;
  }
}
